#!/bin/bash
##This script optimizes the CMB dataset
if [ -z "$1" ]; then export DATA=../data; else export DATA=$1; fi
if [ -z $BIN ]; then export BIN=vargibbs; fi
if [ -z $VER ]; then export VER=./; fi
set -e
export WD=${VER}CMB-global
mkdir -p ${WD}
echo " ******* "
echo " ******* "
echo " ******* This script will take about 30 minutes to run"
echo " ******* "
echo " ******* If you wish to reproduce the files data/AOP-CMB.par and data/BOP-CMB.par"
echo " ******* Edit this script and set MRR=1000 and ASL=0.0001 and be prepared for up to a week of processing"
export MRR=5
export ASL=0.1
echo " ******* "
echo " ******* Starting Global Minimization Round 1"

$BIN  -calc=minglobal -cl=10 -data=${DATA}/D-CMB.dat -gn=0 -me=3000 -minmethod=gsl -mm=6 -mrr=${MRR} \
-o=${WD}/BOP-CMB -par=${DATA}/init_s98.par \
-parid=CMB-x1 -randominitial=0.5 -randomizedataset=0 -rs=1234 \
-var=AT_AT:entropy,AT_CG:entropy,AT_GC:entropy,AT_TA:entropy,CG_AT:entropy,CG_CG:entropy,CG_GC:entropy,GC_AT:entropy,GC_CG:entropy,TA_AT:entropy,AT_AT:enthalpy,AT_CG:enthalpy,AT_GC:enthalpy,AT_TA:enthalpy,CG_AT:enthalpy,CG_CG:enthalpy,CG_GC:enthalpy,GC_AT:enthalpy,GC_CG:enthalpy,TA_AT:enthalpy,terminal_CG_enthalpy,terminal_CG_entropy,terminal_AT_enthalpy,terminal_AT_entropy,symmetry_correction_entropy

echo " ******* "
echo " ******* "
echo " ******* Starting Global Minimization Round 2"
echo " ******* "
echo " ******* "

$BIN  -asl=${ASL} -calc=minglobal -cl=10 -data=${DATA}/D-CMB.dat -gn=0 -ee=0.3 -me=3000 -minmethod=gsl -mm=6 \
-o=${WD}/AOP-CMB -par=${WD}/BOP-CMB.par.best -parid=CMB-x2 \
-randomizedataset=1 -rs=1234 \
-var=AT_AT:entropy,AT_CG:entropy,AT_GC:entropy,AT_TA:entropy,CG_AT:entropy,CG_CG:entropy,CG_GC:entropy,GC_AT:entropy,GC_CG:entropy,TA_AT:entropy,AT_AT:enthalpy,AT_CG:enthalpy,AT_GC:enthalpy,AT_TA:enthalpy,CG_AT:enthalpy,CG_CG:enthalpy,CG_GC:enthalpy,GC_AT:enthalpy,GC_CG:enthalpy,TA_AT:enthalpy,terminal_CG_enthalpy,terminal_CG_entropy,terminal_AT_enthalpy,terminal_AT_entropy,symmetry_correction_entropy

echo " ******* "
echo " ******* "
echo " ******* Calculating predictions with new parameters "
echo " ******* "
echo " ******* "

$BIN  -o=${WD}/CMB-global-prediction -par=${WD}/AOP-CMB.par.best \
-calc=prediction -data=${DATA}/D-CMB.dat
